<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/abstract_preloaded_regular_screen.php';
$g_num = 1;
///////////////////////////////////////////////////////////////////////////

class TvChannelListScreen extends AbstractPreloadedRegularScreen
    implements UserInputHandler
{
    const ID = 'tv_channel_list';

	protected static $hints = array
		(
		'Можно выбрать два варианта запуска плагина. При нажатии кнопки пульта "ENTER" открывается список потоков. Если нажать кнопку "PLAY", то запустится последний просмотренный поток.',
		'Для получения информации о характеристиках текущего потока нужно последовательно нажать кнопки "INFO" и "SELECT".',
		'При невысокой скорости интернет-соединения полезно выбрать поток с меньшим качеством, что позволит избавиться от замираний и артефактов изображения.',
		'Если в поле ввода текста (в основном в настройках) необходимо вводить большое количество символов, можно использовать экранную клавиатуру, нажав синюю кнопку "D".',
		);
    ///////////////////////////////////////////////////////////////////////

    public static function get_media_url_str($group_id)
    {
        return MediaURL::encode(
            array
            (
                'screen_id' => self::ID,
                'group_id'  => $group_id,
            ));
    }

    ///////////////////////////////////////////////////////////////////////

    protected $tv;

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Tv $tv, $folder_views)
    {
        parent::__construct(self::ID, $folder_views);

        $this->tv = $tv;

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }
    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = array();
        $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::tv_play();
        $actions[GUI_EVENT_KEY_PLAY] = ActionFactory::tv_play();

        $open_settings = ActionFactory::open_folder(DemoSetupScreen::get_media_url_str());
        $open_settings['caption'] = 'Настройки';
	    $open_ver = UserInputHandlerRegistry::create_action($this, 'info_version');
	    $ver = HD::ver();
	    $open_ver['caption'] = 'Версия '.$ver;
		$open_help = UserInputHandlerRegistry::create_action($this, 'help');
		$open_help['caption'] = 'Полезно знать';

		$actions[GUI_EVENT_KEY_B_GREEN] = $open_ver;
		$actions[GUI_EVENT_KEY_C_YELLOW] = $open_settings;
	    $actions[GUI_EVENT_KEY_D_BLUE] = $open_help;

        if ($this->tv->is_favorites_supported())
        {
            $add_favorite_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'add_favorite');
            $add_favorite_action['caption'] = 'Favorite';

            $popup_menu_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'popup_menu');

            $actions[GUI_EVENT_KEY_D_BLUE] = $add_favorite_action;
            $actions[GUI_EVENT_KEY_POPUP_MENU] = $popup_menu_action;
        }

        return $actions;
    }
//////////////////////////////////////////////////////////////////////////////////////////

    public function get_handler_id()
    { return self::ID; }

    private function get_sel_item_update_action(&$user_input, &$plugin_cookies)
    {
        $parent_media_url = MediaURL::decode($user_input->parent_media_url);
        $sel_ndx = $user_input->sel_ndx;
        $group = $this->tv->get_group($parent_media_url->group_id);
        $channels = $group->get_channels($plugin_cookies);

        $items[] = $this->get_regular_folder_item($group,
            $channels->get_by_ndx($sel_ndx), $plugin_cookies);
        $range = HD::create_regular_folder_range($items,
            $sel_ndx, $channels->size());

        return ActionFactory::update_regular_folder($range, false);
    }

    public function do_get_help_defs(&$plugin_cookies)
    {
	global $g_num;
	$path = DuneSystem::$properties['install_dir_path'];
	$h_count = count(self::$hints);
	$g1 = '<gap width="40"/>';
	$p1_text1 = '<text size=small color=2>Совет '.$g_num.'</text>';
	$p1_text2 = '<text size=small color=2> ('.$h_count.')</text>';
	$p2_text = '<text dy=-10 size=small color=8> ________________________________________</text>';
	ControlFactory::add_smart_label($defs, null, $p1_text1.$p1_text2.$p2_text);
ControlFactory::add_vgap($defs, -10); 
    $label2 = rtrim(self::$hints[$g_num - 1]);
	#######################################################
	$text = HD::mb_str2arr($label2, 42);
	$cnt = count($text);
	$text = implode("\n", $text);
	if ($cnt < 4)
	$text .= str_repeat("\n", 5 - ($cnt % 5));
	ControlFactory::add_multi_label($defs, null, $text, 4);
	#######################################################
ControlFactory::add_vgap($defs, -10); 
	$p3_text3 = '<text size=small color=2>Навигация</text>';
	$p3_text4 = '<text dy=-10 size=small color=8> _________________________________________</text>';
	ControlFactory::add_smart_label($defs, null, $p3_text3.$p3_text4);

	$button_left = $path.'/icons/left.aai';
	$button_right = $path.'/icons/right.aai';
	$button_up = $path.'/icons/up.aai';
	$button_down = $path.'/icons/down.aai';
	$button_return = $path.'/icons/return.aai';

	$ico_left  = '<icon dy="-5">'.$button_left.'</icon>';
	$ico_right  = '<icon dy="-5">'.$button_right.'</icon>';
	$ico_up  = '<icon dy="-5">'.$button_up.'</icon>';
	$ico_down  = '<icon dy="-5">'.$button_down.'</icon>';
	$ico_return  = '<icon dy="-5">'.$button_return.'</icon>';

	$text_sovet = '<text size=small color=14> Советы</text>';
	$text_scroll = '<text size=small color=14> Скроллинг</text>';
	$text_return = '<text size=small color=14> Закрыть</text>';

ControlFactory::add_vgap($defs, -20);
	ControlFactory::add_smart_label($defs, null, $ico_left.$ico_right.$text_sovet.$g1.$ico_up.$ico_down.$text_scroll.$g1.$ico_return.$text_return);
	 
	return $defs;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
	Global $g_num;
	$control_id = $user_input->control_id;
    foreach ($user_input as $key => $value)

        if ($user_input->control_id == 'close_btn')
		{
        	return  ActionFactory::close_dialog();
		}
        if ($user_input->control_id == 'info_version')
        {
			return  ActionFactory::show_dialog( "КТК", ABOUT::get_plug_info(), true, 720 );
		}
        if ($user_input->control_id == 'popup_menu')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $channel_id = $media_url->channel_id;

            $is_favorite = $this->tv->is_favorite_channel_id($channel_id, $plugin_cookies);
            $add_favorite_action = UserInputHandlerRegistry::create_action($this, 'add_favorite');
            $caption = 'Add to Favorites';
            $menu_items[] = array(
            GuiMenuItemDef::caption => $caption,
            GuiMenuItemDef::action => $add_favorite_action);

            return ActionFactory::show_popup_menu($menu_items);
        }
        if ($user_input->control_id == 'add_favorite')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $channel_id = $media_url->channel_id;

            $is_favorite = $this->tv->is_favorite_channel_id($channel_id, $plugin_cookies);
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog('Channel already resides in Favorites',
                    $this->get_sel_item_update_action($user_input, $plugin_cookies));
            }
            else
            {
                $this->tv->change_tv_favorites(PLUGIN_FAVORITES_OP_ADD,
                    $channel_id, $plugin_cookies);

                return ActionFactory::show_title_dialog(
                    'Channel has been added to Favorites',
                    $this->get_sel_item_update_action(
                        $user_input, $plugin_cookies));
            }
        }
		if ($user_input->control_id == 'help')
		{
			$defs = $this->do_get_help_defs($plugin_cookies);
			return ActionFactory::show_dialog
			("Полезно знать", $defs, true, 900, 
				array
				(
					'actions' => array
					(
						GUI_EVENT_KEY_LEFT => UserInputHandlerRegistry::create_action($this, 'do_show_prev_item'),
						GUI_EVENT_KEY_RIGHT => UserInputHandlerRegistry::create_action($this, 'do_show_next_item'),
					)
				)
			);
		}

		if ($control_id == 'do_show_prev_item')
		{
			if ($g_num > 1)
			$g_num = --$g_num;
			else
			$g_num = count(self::$hints);
		}
		if ($control_id == 'do_show_next_item')
		{
			if ($g_num < count(self::$hints))
			$g_num = ++$g_num;
			else
			$g_num = 1;	
		}

	return ActionFactory::reset_controls($this->do_get_help_defs($plugin_cookies));
    }

    ///////////////////////////////////////////////////////////////////////

    private function get_regular_folder_item($group, $c, &$plugin_cookies)
    {
	$title = $c->get_title();
	$url = $c->get_url();
	$url_arr = explode("/", $url);
	$q = $url_arr[4];
	$epg_server = isset($plugin_cookies->epg_server) ? $plugin_cookies->epg_server : '1';
	if ($epg_server == '1')
	$epg_name = 'От провайдера';
	else if ($epg_server == '2')
	$epg_name = 'Внешний источник';
	else
	$epg_name = 'N/A';

	switch ($q)
		{
		case 'live.hq':
		$size = '604 x 340';
		break;

		case 'live.sq':
		$size = '360 x 204';
		break;

		case 'live.lq':
		$size = '256 x 144';
		break;

		default:
		$size = '720 x 576';
		}

        return array
        (
            PluginRegularFolderItem::media_url =>
                MediaURL::encode(
                    array(
                        'channel_id' => $c->get_id(),
                        'group_id' => $group->get_id())),
            PluginRegularFolderItem::caption => $c->get_title(),
            PluginRegularFolderItem::view_item_params => array
            (
                ViewItemParams::icon_path => $c->get_icon_url(),
                ViewItemParams::item_detailed_icon_path => 'plugin_file://icons/logo.png',
                ViewItemParams::item_detailed_info => "Поток:|$title||Разрешение:|$size||Источник телепрограммы:|$epg_name",
            ),
            PluginRegularFolderItem::starred =>
                $this->tv->is_favorite_channel_id(
                    $c->get_id(), $plugin_cookies),
        );
    }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->tv->folder_entered($media_url, $plugin_cookies);

        $this->tv->ensure_channels_loaded($plugin_cookies);

        $group = $this->tv->get_group($media_url->group_id);

        $items = array();

        foreach ($group->get_channels($plugin_cookies) as $c)
        {
            $items[] = $this->get_regular_folder_item(
                $group, $c, $plugin_cookies);
        }

        return $items;
    }

    public function get_archive(MediaURL $media_url)
    {
        return $this->tv->get_archive($media_url);
    }



}

///////////////////////////////////////////////////////////////////////////
?>
