<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/hashed_array.php';
require_once 'lib/tv/abstract_tv.php';
require_once 'lib/tv/default_epg_item.php';

require_once 'plugtv_channel.php';
require_once 'lib/etools.php';
///////////////////////////////////////////////////////////////////////////

class DemoTv extends AbstractTv
{
    public function __construct()
    {
        parent::__construct(
            AbstractTv::MODE_CHANNELS_N_TO_M,
            DemoConfig::TV_FAVORITES_SUPPORTED,
            true);
    }

    public function get_fav_icon_url()
    {
//        return DemoConfig::FAV_CHANNEL_GROUP_ICON_PATH;
        return null;
    }

    ///////////////////////////////////////////////////////////////////////
     public function get_tv_playback_url($channel_id, $archive_ts, $protect_code, &$plugin_cookies)
    {
        $url = $this->get_channel($channel_id)->get_streaming_url();
        $url = str_replace('http://', 'http://ts://', $url);		
        $buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
		if ($buf_time > 0)
		$url .= '|||dune_params|||buffering_ms:'.$buf_time;
        return $url;
    }
    ///////////////////////////////////////////////////////////////////////
    public function folder_entered(MediaURL $media_url, &$plugin_cookies)
	{
	if ($media_url->get_raw_string() == 'tv_channel_list')
                $this->load_channels($plugin_cookies);            
	}
    ///////////////////////////////////////////////////////////////////////

    protected function load_channels(&$plugin_cookies)
    {
        try
        {
	     $doc = file_get_contents(DemoConfig::CHANNEL_LIST_URL, true);
        }
        catch (Exception $e)
        {
            throw new DuneException(
                'HTTP network error', 0,
                ActionFactory::show_error(
                    true,
                    'Ошибка связи',
                    array(
                        'Не удаётся подключиться к IPTV-серверу.',
                        'Проверьте подключение к сети Интернет.')));
        }
     
        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text: $doc.");
            throw new Exception('Illegal XML document');
        }

        if ($xml->getName() !== 'tv_info')
        {
            hd_print("Error: unexpected node '" . $xml->getName() . "'. Expected: 'tv_info'");
            throw new Exception('Invalid XML document');
        }

        $this->channels = new HashedArray();
        $this->groups = new HashedArray();

        if ($this->is_favorites_supported())
        {
            $this->groups->put(
                new FavoritesGroup(
                    $this,
                    '__favorites',
					'',
					''));
        }

        $this->groups->put(
            new AllChannelsGroup(
                $this,
				'',
				''));

        foreach ($xml->tv_categories->children() as $xml_tv_category)
        {
            if ($xml_tv_category->getName() !== 'tv_category')
            {
                hd_print("Error: unexpected node '" . $xml_tv_category->getName() .
                    "'. Expected: 'tv_category'");
                throw new Exception('Invalid XML document');
            }

            $this->groups->put(
                new DefaultGroup(
                    strval($xml_tv_category->id),
                    strval($xml_tv_category->caption),
                    strval($xml_tv_category->icon_url)));
        }

        foreach ($xml->tv_channels->children() as $xml_tv_channel)
        {
	    $ch_hide = $xml_tv_channel->hide;
            if ($xml_tv_channel->getName() !== 'tv_channel')
            {
                hd_print("Error: unexpected node '" . $xml_tv_channel->getName() .
                    "'. Expected: 'tv_channel'");
                throw new Exception('Invalid XML document');
            }

            $channel =
                new DemoChannel(
                    strval($xml_tv_channel->id),
                    strval($xml_tv_channel->caption),
                    strval($xml_tv_channel->icon_url),
                    strval($xml_tv_channel->streaming_url),
                    intval($xml_tv_channel->number),
                    intval($xml_tv_channel->num_past_epg_days),
                    intval($xml_tv_channel->num_future_epg_days),
                    strval($xml_tv_channel->epg_cod),
                    strval($xml_tv_channel->description),
                    intval($xml_tv_channel->archive));

            $this->channels->put($channel);

            foreach ($xml_tv_channel->tv_categories->children() as $xml_tv_cat_id)
            {
                if ($xml_tv_cat_id->getName() !== 'tv_category_id')
                {
                    hd_print("Error: unexpected node '" . $xml_tv_cat_id->getName() .
                        "'. Expected: 'tv_category_id'");
                    throw new Exception('Invalid XML document');
                }

                $tv_category_id = intval($xml_tv_cat_id);

                $group = $this->groups->get($tv_category_id);

                // Link group and channel.

                $channel->add_group($group);
                $group->add_channel($channel);
            }
        }

        if (DemoConfig::CHANNEL_SORT_FUNC_CB != null)
            $this->channels->usort(DemoConfig::CHANNEL_SORT_FUNC_CB);
    }

    ///////////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////

    public function get_day_epg_iterator($channel_id, $day_start_ts, &$plugin_cookies)
    {
	$epg_server = isset($plugin_cookies->epg_server) ? $plugin_cookies->epg_server : '1';
	$epg_shift = isset($plugin_cookies->epg_shift) ? $plugin_cookies->epg_shift : 0;
    $local_tz = HD::get_local_time_zone();
    $local_tz_offset = HD::get_local_time_zone_offset();
    $epg_date = date("Y-m-d", $day_start_ts);
    $epg = array();
    $doc = ""; 
    $ch_shift = 0;
///===========================================================================
    if ($epg_server == '1')					// КТК
	{
	$doc = ET::get_epg_ktk($day_start_ts);
	}
///===========================================================================
    else if ($epg_server == '2')			// Алма ТВ
	{
	$doc = ET::get_epg_almatv($day_start_ts);
	}
///===========================================================================
	if(empty($doc))
	return array();	
	
    preg_match_all("/([0-2]{0,1}[0-9][\.\:][0-5][0-9])([^\n]+)\n/", $doc, $matches);

/////////////////////////////////////////////////////////////////////////////////////////////////////
       $epg_date = date("Y-m-d", $day_start_ts);
       $last_time = 0;

        foreach ($matches[1] as $key => $time) {
//	    $str = preg_split("/\|/", $matches[2][$key], 2);
	    $str = preg_split("/\|/", $matches[2][$key]);
	    $name = $str[0];
	    $desc = array_key_exists(1, $str) ? $str[1] : "";
	    $u_time = strtotime("$epg_date $time $local_tz")+$ch_shift;
	    $last_time = ($u_time < $last_time) ? $u_time + 86400  : $u_time ;
	    $epg[$last_time]["name"] = $name;
	    $epg[$last_time]["desc"] = $desc;
	    }
		$epg_result = array();

	ksort($epg, SORT_NUMERIC);
	reset($epg);

	foreach ($epg as $time => $value) {
	    $epg_result[] =
                new DefaultEpgItem(
                    strval($value['name']),
                    strval($value['desc']),
                    intval($time + $epg_shift),
//                    intval($time),
                    intval(-1));
	}
	
	return
            new EpgIterator(
                $epg_result,
                $day_start_ts - $local_tz_offset,
                $day_start_ts + 100400);     

    }
}

///////////////////////////////////////////////////////////////////////////
?>
